# example

[![PyPI - Version](https://img.shields.io/pypi/v/example.svg)](https://pypi.org/project/example)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/example.svg)](https://pypi.org/project/example)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install example
```

## License

`example` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
